<?php

namespace Litepie\Masters\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\Masters\Http\Requests\DistributionareaRequest;
use Litepie\Masters\Interfaces\DistributionareaRepositoryInterface;
use Litepie\Masters\Models\Distributionarea;
use Litepie\Masters\Forms\Distributionarea as Form;

/**
 * APIController  class for distributionarea.
 */
class DistributionareaAPIController extends BaseController
{

    /**
     * Initialize distributionarea resource controller.
     *
     * @param type DistributionareaRepositoryInterface $distributionarea
     *
     * @return null
     */
    public function __construct(DistributionareaRepositoryInterface $distributionarea)
    {
        parent::__construct();
        $this->repository = $distributionarea;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Masters\Repositories\Criteria\DistributionareaResourceCriteria::class);
    }

    /**
     * Display a list of distributionarea.
     *
     * @return Response
     */
    public function index(DistributionareaRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\Masters\Repositories\Presenter\DistributionareaPresenter::class)
            ->paginate();
    }

    /**
     * Display distributionarea.
     *
     * @param Request $request
     * @param Model   $distributionarea
     *
     * @return Response
     */
    public function show(DistributionareaRequest $request, Distributionarea $distributionarea)
    {
        return $distributionarea->setPresenter(\Litepie\Masters\Repositories\Presenter\DistributionareaListPresenter::class);
        ;
    }

    /**
     * Create new distributionarea.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DistributionareaRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('masters::distributionarea.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('masters/distributionarea/' . $distributionarea->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('masters/distributionarea');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the distributionarea.
     *
     * @param Request $request
     * @param Model   $distributionarea
     *
     * @return Response
     */
    public function update(DistributionareaRequest $request, Distributionarea $distributionarea)
    {
        try {
            $data = $request->all();

            $distributionarea->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('masters::distributionarea.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('masters/distributionarea/' . $distributionarea->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('masters/distributionarea/' . $distributionarea->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the distributionarea.
     *
     * @param Model   $distributionarea
     *
     * @return Response
     */
    public function destroy(DistributionareaRequest $request, Distributionarea $distributionarea)
    {
        try {
            $distributionarea->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('masters::distributionarea.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('masters/distributionarea/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('masters/distributionarea/' . $distributionarea->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
