<?php

namespace Litepie\Masters\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Masters\Interfaces\MediatypeRepositoryInterface;

class MediatypePublicController extends BaseController
{
    // use MediatypeWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\Mediatype\Interfaces\MediatypeRepositoryInterface $mediatype
     *
     * @return type
     */
    public function __construct(MediatypeRepositoryInterface $mediatype)
    {
        $this->repository = $mediatype;
        parent::__construct();
    }

    /**
     * Show mediatype's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $mediatypes = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('masters::mediatype.names'))
            ->view('masters::public.mediatype.index')
            ->data(compact('mediatypes'))
            ->output();
    }


    /**
     * Show mediatype.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $mediatype = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($mediatype->name . trans('masters::mediatype.name'))
            ->view('masters::public.mediatype.show')
            ->data(compact('mediatype'))
            ->output();
    }

}
