<?php

namespace Litepie\Masters\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Masters\Interfaces\StatusRepositoryInterface;

class StatusPublicController extends BaseController
{
    // use StatusWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\Status\Interfaces\StatusRepositoryInterface $status
     *
     * @return type
     */
    public function __construct(StatusRepositoryInterface $status)
    {
        $this->repository = $status;
        parent::__construct();
    }

    /**
     * Show status's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $statuses = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('masters::status.names'))
            ->view('masters::public.status.index')
            ->data(compact('statuses'))
            ->output();
    }


    /**
     * Show status.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $status = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($status->name . trans('masters::status.name'))
            ->view('masters::public.status.show')
            ->data(compact('status'))
            ->output();
    }

}
