<?php

namespace Litepie\Masters\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Masters\Models\Distributionarea;

class DistributionareaPolicy
{

    /**
     * Determine if the given user can view the distributionarea.
     *
     * @param UserPolicy $user
     * @param Distributionarea $distributionarea
     *
     * @return bool
     */
    public function view(UserPolicy $user, Distributionarea $distributionarea)
    {
        if ($user->canDo('masters.distributionarea.view') && $user->isAdmin()) {
            return true;
        }

        return $distributionarea->user_id == user_id() && $distributionarea->user_type == user_type();
    }

    /**
     * Determine if the given user can create a distributionarea.
     *
     * @param UserPolicy $user
     * @param Distributionarea $distributionarea
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('masters.distributionarea.create');
    }

    /**
     * Determine if the given user can update the given distributionarea.
     *
     * @param UserPolicy $user
     * @param Distributionarea $distributionarea
     *
     * @return bool
     */
    public function update(UserPolicy $user, Distributionarea $distributionarea)
    {
        if ($user->canDo('masters.distributionarea.edit') && $user->isAdmin()) {
            return true;
        }

        return $distributionarea->user_id == user_id() && $distributionarea->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given distributionarea.
     *
     * @param UserPolicy $user
     * @param Distributionarea $distributionarea
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Distributionarea $distributionarea)
    {
        return $distributionarea->user_id == user_id() && $distributionarea->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given distributionarea.
     *
     * @param UserPolicy $user
     * @param Distributionarea $distributionarea
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Distributionarea $distributionarea)
    {
        if ($user->canDo('masters.distributionarea.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given distributionarea.
     *
     * @param UserPolicy $user
     * @param Distributionarea $distributionarea
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Distributionarea $distributionarea)
    {
        if ($user->canDo('masters.distributionarea.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
