<?php

namespace Litepie\Masters\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Masters\Models\Linkinfo;

class LinkinfoPolicy
{

    /**
     * Determine if the given user can view the linkinfo.
     *
     * @param UserPolicy $user
     * @param Linkinfo $linkinfo
     *
     * @return bool
     */
    public function view(UserPolicy $user, Linkinfo $linkinfo)
    {
        if ($user->canDo('masters.linkinfo.view') && $user->isAdmin()) {
            return true;
        }

        return $linkinfo->user_id == user_id() && $linkinfo->user_type == user_type();
    }

    /**
     * Determine if the given user can create a linkinfo.
     *
     * @param UserPolicy $user
     * @param Linkinfo $linkinfo
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('masters.linkinfo.create');
    }

    /**
     * Determine if the given user can update the given linkinfo.
     *
     * @param UserPolicy $user
     * @param Linkinfo $linkinfo
     *
     * @return bool
     */
    public function update(UserPolicy $user, Linkinfo $linkinfo)
    {
        if ($user->canDo('masters.linkinfo.edit') && $user->isAdmin()) {
            return true;
        }

        return $linkinfo->user_id == user_id() && $linkinfo->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given linkinfo.
     *
     * @param UserPolicy $user
     * @param Linkinfo $linkinfo
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Linkinfo $linkinfo)
    {
        return $linkinfo->user_id == user_id() && $linkinfo->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given linkinfo.
     *
     * @param UserPolicy $user
     * @param Linkinfo $linkinfo
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Linkinfo $linkinfo)
    {
        if ($user->canDo('masters.linkinfo.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given linkinfo.
     *
     * @param UserPolicy $user
     * @param Linkinfo $linkinfo
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Linkinfo $linkinfo)
    {
        if ($user->canDo('masters.linkinfo.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
