<?php

namespace Litepie\Masters\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Masters\Models\Mediatype;

class MediatypePolicy
{

    /**
     * Determine if the given user can view the mediatype.
     *
     * @param UserPolicy $user
     * @param Mediatype $mediatype
     *
     * @return bool
     */
    public function view(UserPolicy $user, Mediatype $mediatype)
    {
        if ($user->canDo('masters.mediatype.view') && $user->isAdmin()) {
            return true;
        }

        return $mediatype->user_id == user_id() && $mediatype->user_type == user_type();
    }

    /**
     * Determine if the given user can create a mediatype.
     *
     * @param UserPolicy $user
     * @param Mediatype $mediatype
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('masters.mediatype.create');
    }

    /**
     * Determine if the given user can update the given mediatype.
     *
     * @param UserPolicy $user
     * @param Mediatype $mediatype
     *
     * @return bool
     */
    public function update(UserPolicy $user, Mediatype $mediatype)
    {
        if ($user->canDo('masters.mediatype.edit') && $user->isAdmin()) {
            return true;
        }

        return $mediatype->user_id == user_id() && $mediatype->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given mediatype.
     *
     * @param UserPolicy $user
     * @param Mediatype $mediatype
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Mediatype $mediatype)
    {
        return $mediatype->user_id == user_id() && $mediatype->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given mediatype.
     *
     * @param UserPolicy $user
     * @param Mediatype $mediatype
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Mediatype $mediatype)
    {
        if ($user->canDo('masters.mediatype.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given mediatype.
     *
     * @param UserPolicy $user
     * @param Mediatype $mediatype
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Mediatype $mediatype)
    {
        if ($user->canDo('masters.mediatype.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
