<?php

namespace Litepie\Masters\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Masters\Models\Targetgroup;

class TargetgroupPolicy
{

    /**
     * Determine if the given user can view the targetgroup.
     *
     * @param UserPolicy $user
     * @param Targetgroup $targetgroup
     *
     * @return bool
     */
    public function view(UserPolicy $user, Targetgroup $targetgroup)
    {
        if ($user->canDo('masters.targetgroup.view') && $user->isAdmin()) {
            return true;
        }

        return $targetgroup->user_id == user_id() && $targetgroup->user_type == user_type();
    }

    /**
     * Determine if the given user can create a targetgroup.
     *
     * @param UserPolicy $user
     * @param Targetgroup $targetgroup
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('masters.targetgroup.create');
    }

    /**
     * Determine if the given user can update the given targetgroup.
     *
     * @param UserPolicy $user
     * @param Targetgroup $targetgroup
     *
     * @return bool
     */
    public function update(UserPolicy $user, Targetgroup $targetgroup)
    {
        if ($user->canDo('masters.targetgroup.edit') && $user->isAdmin()) {
            return true;
        }

        return $targetgroup->user_id == user_id() && $targetgroup->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given targetgroup.
     *
     * @param UserPolicy $user
     * @param Targetgroup $targetgroup
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Targetgroup $targetgroup)
    {
        return $targetgroup->user_id == user_id() && $targetgroup->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given targetgroup.
     *
     * @param UserPolicy $user
     * @param Targetgroup $targetgroup
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Targetgroup $targetgroup)
    {
        if ($user->canDo('masters.targetgroup.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given targetgroup.
     *
     * @param UserPolicy $user
     * @param Targetgroup $targetgroup
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Targetgroup $targetgroup)
    {
        if ($user->canDo('masters.targetgroup.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
