<?php

namespace Litepie\Master\Providers;

use Illuminate\Support\ServiceProvider;

class MasterServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'master');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'master');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerMaster();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerMaster()
    {
        $this->app->bind('master', function($app) {
            return new Master($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Master', 'Lavalite\Master\Facades\Master');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litepie.master', function ($app) {
            return $this->app->make('Litepie\Master\Master');
        });

        // Bind Distributionarea to repository
        $this->app->bind(
            'Litepie\Master\Interfaces\DistributionareaRepositoryInterface',
            \Litepie\Master\Repositories\Eloquent\DistributionareaRepository::class
        );        // Bind Targetgroup to repository
        $this->app->bind(
            'Litepie\Master\Interfaces\TargetgroupRepositoryInterface',
            \Litepie\Master\Repositories\Eloquent\TargetgroupRepository::class
        );        // Bind Linkinfo to repository
        $this->app->bind(
            'Litepie\Master\Interfaces\LinkinfoRepositoryInterface',
            \Litepie\Master\Repositories\Eloquent\LinkinfoRepository::class
        );        // Bind Status to repository
        $this->app->bind(
            'Litepie\Master\Interfaces\StatusRepositoryInterface',
            \Litepie\Master\Repositories\Eloquent\StatusRepository::class
        );        // Bind Mediatype to repository
        $this->app->bind(
            'Litepie\Master\Interfaces\MediatypeRepositoryInterface',
            \Litepie\Master\Repositories\Eloquent\MediatypeRepository::class
        );

        $this->app->register(\Litepie\Master\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litepie\Master\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and master's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litepie.master'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeMaster::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepie.master'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litepie/master.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/master')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/master')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
