<?php

namespace Litepie\Masters\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litepie\Masters\Models\Masters;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litepie\Masters\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/masters/distributionarea/*')) {
            Route::bind('distributionarea', function ($distributionarea) {
                $distributionarearepo = $this->app->make('Litepie\Masters\Interfaces\DistributionareaRepositoryInterface');
                return $distributionarearepo->findorNew($distributionarea);
            });
        }

        if (Request::is('*/masters/targetgroup/*')) {
            Route::bind('targetgroup', function ($targetgroup) {
                $targetgrouprepo = $this->app->make('Litepie\Masters\Interfaces\TargetgroupRepositoryInterface');
                return $targetgrouprepo->findorNew($targetgroup);
            });
        }

        if (Request::is('*/masters/linkinfo/*')) {
            Route::bind('linkinfo', function ($linkinfo) {
                $linkinforepo = $this->app->make('Litepie\Masters\Interfaces\LinkinfoRepositoryInterface');
                return $linkinforepo->findorNew($linkinfo);
            });
        }

        if (Request::is('*/masters/status/*')) {
            Route::bind('status', function ($status) {
                $statusrepo = $this->app->make('Litepie\Masters\Interfaces\StatusRepositoryInterface');
                return $statusrepo->findorNew($status);
            });
        }

        if (Request::is('*/masters/mediatype/*')) {
            Route::bind('mediatype', function ($mediatype) {
                $mediatyperepo = $this->app->make('Litepie\Masters\Interfaces\MediatypeRepositoryInterface');
                return $mediatyperepo->findorNew($mediatype);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
